@@ -1,23 +1,16 @@
-;# $Id: dump.pl,v 0.7 2000/08/03 22:04:45 ram Exp $
+;# $Id: dump.pl,v 0.3 1997/01/14 14:57:46 ram Exp $
 ;#
-;#  Copyright (c) 1995-2000, Raphael Manfredi
+;#  Copyright (c) 1995-1997, Raphael Manfredi
 ;#  
 ;#  You may redistribute only under the terms of the Artistic License,
 ;#  as specified in the README file that comes with the distribution.
 ;#
 ;# $Log: dump.pl,v $
-;# Revision 0.7  2000/08/03 22:04:45  ram
-;# Baseline for second beta release.
+;# Revision 0.3  1997/01/14  14:57:46  ram
+;# Baseline for third netwide alpha release.
 ;#
 
-sub ok {
-	my ($num, $ok) = @_;
-	print "not " unless $ok;
-	print "ok $num\n";
-}
-
 package dump;
-use Carp;
 
 %dump = (
 	'SCALAR'	=> 'dump_scalar',
@@ -29,7 +22,7 @@ use Carp;
 # Given an object, dump its transitive data closure
 sub main'dump {
 	my ($object) = @_;
-	croak "Not a reference!" unless ref($object);
+	die "Not a reference!\n" unless ref($object);
 	local %dumped;
 	local %object;
 	local $count = 0;
@@ -70,19 +63,16 @@ sub recursive_dump {
 		return;
 	}
 
-	my $objcount = $count++;
-	$object{$addr} = $objcount;
-
 	# Call the appropriate dumping routine based on the reference type.
 	# If the referenced was blessed, we bless it once the object is dumped.
 	# The retrieval code will perform the same on the last object retrieved.
 
-	croak "Unknown simple type '$ref'" unless defined $dump{$ref};
-
+	die "Unknown simple type '$ref'\n" unless defined $dump{$ref};
 	&{$dump{$ref}}($object);	# Dump object
 	&bless($bless) if $bless;	# Mark it as blessed, if necessary
 
-	$dumped .= "OBJECT $objcount\n";
+	$dumped .= "OBJECT $count\n";
+	$object{$addr} = $count++;
 }
 
 # Indicate that current object is blessed
